#ifndef PASSWDGEN_H
#define PASSWDGEN_H

#include <stdio.h>

#include <Constants.h>

using namespace std;


typedef enum {numeric, snumeric, alpha, alphanumeric} BruteForceRange;
typedef long long int pwdnum;

class PasswdGen
{
	public:
	PasswdGen(pwdnum myfirst, pwdnum mylast);
	~PasswdGen();

	virtual char *Type();
	virtual pwdnum TotalPasswds();
	virtual void NextPasswd(
		char passwd[BIGGEST_PASSWORD],
		bool *nomorepasswds);
	
	pwdnum GetFirst();
	pwdnum GetLast();
	
	protected:
	pwdnum first;
	pwdnum last;
};


class BruteForcePasswdGen : public PasswdGen
{
	public:
	BruteForcePasswdGen(
		int mylength,
		BruteForceRange myrange,
		pwdnum myfirst,
		pwdnum mylast);
	~BruteForcePasswdGen();

	char *Type();
	pwdnum TotalPasswds();
	void NextPasswd(char passwd[BIGGEST_PASSWORD], bool *nomorepasswds);
	int MaxLength();
	BruteForceRange Range();
	
	private:
	int maxlength;
	BruteForceRange range;
	pwdnum current;
	pwdnum fakecurrent;
	pwdnum total;
	pwdnum faketotal;
};


class DictionaryPasswdGen : public PasswdGen
{
	public:
	DictionaryPasswdGen(
		char myfilename[BIGGEST_FILENAME],
		pwdnum myfirst,
		pwdnum mylast);
	~DictionaryPasswdGen();

	char *Type();
	pwdnum TotalPasswds();
	void NextPasswd(char passwd[BIGGEST_PASSWORD], bool *nomorepasswds);
	char *Filename();
	
	private:
	
	char filename[BIGGEST_FILENAME];
	FILE *fd;
	long int current;
};

#endif

